@@ -89,7 +89,6 @@
 #![feature(alloc_layout_extra)]
 #![feature(allocator_api)]
 #![feature(array_into_iter_constructors)]
-#![feature(array_windows)]
 #![feature(ascii_char)]
 #![feature(assert_matches)]
 #![feature(async_fn_traits)]
@@ -127,7 +126,6 @@
 #![feature(layout_for_ptr)]
 #![feature(legacy_receiver_trait)]
 #![feature(local_waker)]
-#![feature(maybe_uninit_slice)]
 #![feature(maybe_uninit_uninit_array_transpose)]
 #![feature(panic_internals)]
 #![feature(pattern)]
